Functions
- ask
- Ask the user how they want to create the project
- from_
custom_ remote_ repository - Creates the repository project from a remote repository
- from_
cutom_ local_ repository - Creates the repository project from a local repository (probably not a good thing)
- from_
official_ repository - Creates the repository project from one of the official template of wini
- handle_
project_ setup_ for_ custom - Ask informations about the branch and the project name, and proceed to setup the repository correctly.