Module ask

Module ask 

Functions

ask
Ask the user how they want to create the project
from_custom_remote_repository
Creates the repository project from a remote repository
from_cutom_local_repository
Creates the repository project from a local repository (probably not a good thing)
from_official_repository
Creates the repository project from one of the official template of wini
handle_project_setup_for_custom
Ask informations about the branch and the project name, and proceed to setup the repository correctly.